@@ -7,7 +7,7 @@ from click import progressbar
 from scout.build.disease import build_disease_term
 from scout.build.hpo import build_hpo_term
 from scout.parse.hpo_mappings import parse_hpo_diseases, parse_hpo_to_genes
-from scout.parse.hpo_terms import build_hpo_tree, parse_hpo_obo
+from scout.parse.hpo_terms import build_hpo_tree
 from scout.parse.omim import get_mim_phenotypes
 from scout.utils.scout_requests import fetch_hpo_terms, fetch_hpo_to_genes_to_disease
 
@@ -111,7 +111,6 @@ def load_hpo_terms(adapter, hpo_lines=None, hpo_gene_lines=None, alias_genes=Non
     nr_terms = len(hpo_terms)
     hpo_bulk = []
     with progressbar(hpo_terms.values(), label="Loading hpo terms", length=nr_terms) as bar:
-
         for hpo_info in bar:
             hpo_bulk.append(build_hpo_term(hpo_info))
 
