@@ -1,11 +1,11 @@
 import logging
-import re
 
 from flask import Blueprint, current_app, flash, jsonify, redirect, request, url_for
 from flask_login import current_user
 from markupsafe import Markup
 
 from scout.constants import ACMG_CRITERIA, ACMG_MAP
+from scout.server.blueprints.variant.controllers import check_reset_variant_classification
 from scout.server.blueprints.variant.controllers import evaluation as evaluation_controller
 from scout.server.blueprints.variant.controllers import observations, str_variant_reviewer
 from scout.server.blueprints.variant.controllers import variant as variant_controller
@@ -89,7 +89,7 @@ def cancer_variant(institute_id, case_name, variant_id):
 @templated("variant/sv-variant.html")
 def sv_variant(institute_id, case_name, variant_id):
     """Display a specific structural variant."""
-    data = variant_controller(store, institute_id, case_name, variant_id, add_other=False)
+    data = variant_controller(store, institute_id, case_name, variant_id)
 
     if data is None:
         flash("An error occurred while retrieving variant object", "danger")
@@ -141,6 +141,7 @@ def variant_acmg(institute_id, case_name, variant_id):
                 term=term,
                 comment=request.form.get("comment-{}".format(term)),
                 links=[request.form.get("link-{}".format(term))],
+                modifier=request.form.get("modifier-{}".format(term)),
             )
         )
     acmg = variant_acmg_post(
@@ -184,12 +185,9 @@ def variant_update(institute_id, case_name, variant_id):
             institute_obj, case_obj, user_obj, link, variant_obj, new_manual_rank
         )
         if new_manual_rank:
-            flash("updated variant tag: {}".format(new_manual_rank), "info")
+            flash("Variant tag was updated", "info")
         else:
-            flash(
-                "reset variant tag: {}".format(variant_obj.get("manual_rank", "NA")),
-                "info",
-            )
+            flash("Variant tag was reset", "info")
     elif cancer_tier:
         try:
             new_cancer_tier = cancer_tier if cancer_tier != "-1" else None
@@ -202,12 +200,9 @@ def variant_update(institute_id, case_name, variant_id):
             institute_obj, case_obj, user_obj, link, variant_obj, new_cancer_tier
         )
         if new_cancer_tier:
-            flash("updated variant tag: {}".format(new_cancer_tier), "info")
+            flash("Variant tag was updated", "info")
         else:
-            flash(
-                "reset variant tag: {}".format(variant_obj.get("cancer_tier", "NA")),
-                "info",
-            )
+            flash("Variant tag was reset", "info")
     elif request.form.get("acmg_classification"):
         new_acmg = request.form["acmg_classification"]
         acmg_classification = variant_obj.get("acmg_classification")
@@ -268,6 +263,7 @@ def variant_update(institute_id, case_name, variant_id):
 @templated("variant/acmg.html")
 def evaluation(evaluation_id):
     """Show or delete an ACMG evaluation."""
+
     evaluation_obj = store.get_evaluation(evaluation_id)
     if evaluation_obj is None:
         flash("Evaluation was not found in database", "warning")
@@ -281,6 +277,10 @@ def evaluation(evaluation_id):
             variant_id=evaluation_obj["variant_specific"],
         )
         store.delete_evaluation(evaluation_obj)
+
+        if check_reset_variant_classification(store, evaluation_obj, link):
+            flash("Cleared ACMG classification.", "info")
+
         return redirect(link)
     return dict(
         evaluation=evaluation_obj,
