@@ -3,7 +3,7 @@ import re
 from datetime import date
 
 import bson
-from flask import Response, flash, url_for
+from flask import Response, flash, session, url_for
 from flask_login import current_user
 from pymongo.errors import DocumentTooLarge
 from werkzeug.datastructures import Headers, MultiDict
@@ -27,6 +27,7 @@ from scout.server.blueprints.variant.utils import (
     clinsig_human,
     predictions,
     update_representative_gene,
+    update_variant_case_panels,
 )
 from scout.server.links import add_gene_links, cosmic_links, str_source_link
 from scout.server.utils import (
@@ -37,6 +38,7 @@ from scout.server.utils import (
 )
 
 from .forms import FILTERSFORMCLASS, CancerSvFiltersForm, SvFiltersForm
+from .utils import update_case_panels
 
 LOG = logging.getLogger(__name__)
 
@@ -82,6 +84,8 @@ def variants(
 
     case_dismissed_vars = store.case_dismissed_variants(institute_obj, case_obj)
 
+    update_case_panels(store, case_obj)
+
     variants = []
     for variant_obj in variant_res:
         overlapping_svs = list(store.overlapping(variant_obj))
@@ -120,6 +124,8 @@ def variants(
         if case_obj.get("group"):
             variant_obj["group_assessments"] = _get_group_assessments(store, case_obj, variant_obj)
 
+        update_variant_case_panels(store, case_obj, variant_obj)
+
         variants.append(
             parse_variant(
                 store,
@@ -1149,7 +1155,7 @@ def cancer_variants(store, institute_id, case_name, variants_query, variant_coun
     """Fetch data related to cancer variants for a case.
 
     For each variant, if one or more gene panels are selected, assign the gene present
-    in the panel as the second representative gene. If no gene panel is selected dont assign such a gene.
+    in the panel as the second representative gene. If no gene panel is selected don't assign such a gene.
     """
 
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
@@ -1754,3 +1760,17 @@ def dismiss_variant_list(store, institute_obj, case_obj, link_page, variants_lis
         store.update_dismiss_variant(
             institute_obj, case_obj, user_obj, link, variant_obj, dismiss_reasons
         )
+
+
+def get_show_dismiss_block():
+    """Return the contents of this user session show dismiss block setting.
+    The first time around it may be undefined / None, and in that case we set it to True
+    to default to showing the dismiss bar.
+    """
+
+    show_dismiss_block = session.get("show_dismiss_block")
+    if show_dismiss_block is None:
+        show_dismiss_block = True
+        session["show_dismiss_block"] = show_dismiss_block
+
+    return show_dismiss_block
