@@ -1,12 +1,5 @@
-import datetime
-import logging
 from copy import deepcopy
 
-import pymongo
-import pytest
-
-from scout.constants import VERBS_MAP
-
 
 def test_matching_tiered(adapter, institute_obj, cancer_case_obj, user_obj, cancer_variant_obj):
     """Test retrieving matching tiered variants from other cancer cases"""
@@ -40,8 +33,48 @@ def test_matching_tiered(adapter, institute_obj, cancer_case_obj, user_obj, canc
     assert matching_tiered == {"1A": {"label": "danger", "links": {"link"}}}
 
 
-def test_mark_causative(adapter, institute_obj, case_obj, user_obj, variant_obj):
+def test_matching_manual_rank(
+    adapter, institute_obj, cancer_case_obj, user_obj, cancer_variant_obj
+):
+    """Test retrieving matching manual ranked variants from other cases"""
 
+    # GIVEN a database containing a variant in another case
+    other_var = deepcopy(cancer_variant_obj)
+    other_var["_id"] = "another_id"
+    other_var["case"] = cancer_case_obj["_id"]
+    other_var["manual_rank"] = 10
+    other_var["owner"] = institute_obj["_id"]
+    adapter.variant_collection.insert_one(other_var)
+
+    manual_rank = 10
+
+    # GIVEN that the other variant is ranked
+    adapter.update_manual_rank(
+        institute=institute_obj,
+        case=cancer_case_obj,
+        user=user_obj,
+        link="link",
+        variant=other_var,
+        manual_rank=manual_rank,
+    )
+
+    # WHEN retrieving other manually ranked variants matching the query variant
+    matching_ranked = adapter.get_matching_manual_ranked_variants(
+        query_variant=cancer_variant_obj, user_institutes=[{"_id": "cust000"}]
+    )
+
+    # THEN it should return a set with the other variant tier info
+    assert matching_ranked == {
+        10: {
+            "description": "Established risk allele - strong evidence for a small risk increase",
+            "label_class": "default",
+            "label": "RF",
+            "links": {"link"},
+        }
+    }
+
+
+def test_mark_causative(adapter, institute_obj, case_obj, user_obj, variant_obj):
     # GIVEN a populated database with variants
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
@@ -75,7 +108,6 @@ def test_mark_causative(adapter, institute_obj, case_obj, user_obj, variant_obj)
 
 
 def test_unmark_causative(adapter, institute_obj, case_obj, user_obj, variant_obj):
-
     ## GIVEN a adapter with a variant that is marked causative
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
@@ -113,7 +145,6 @@ def test_unmark_causative(adapter, institute_obj, case_obj, user_obj, variant_ob
 
 
 def test_mark_partial_causative(adapter, institute_obj, case_obj, user_obj, variant_obj):
-
     # GIVEN a populated database with variants
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
@@ -150,7 +181,6 @@ def test_mark_partial_causative(adapter, institute_obj, case_obj, user_obj, vari
 
 
 def test_unmark_partial_causative(adapter, institute_obj, case_obj, user_obj, variant_obj):
-
     # GIVEN a populated database with variants
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
@@ -196,7 +226,6 @@ def test_unmark_partial_causative(adapter, institute_obj, case_obj, user_obj, va
 
 
 def test_order_verification(adapter, institute_obj, case_obj, user_obj, variant_obj):
-
     # GIVEN a populated database with variants
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
@@ -235,7 +264,6 @@ def test_order_verification(adapter, institute_obj, case_obj, user_obj, variant_
 
 
 def test_cancel_verification(adapter, institute_obj, case_obj, user_obj, variant_obj):
-
     # GIVEN a populated database with a variant that has sanger ordered
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
@@ -275,7 +303,6 @@ def test_cancel_verification(adapter, institute_obj, case_obj, user_obj, variant
 
 
 def test_dismiss_variant(adapter, institute_obj, case_obj, user_obj, variant_obj):
-
     # GIVEN a variant db with at least one variant, and no events
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
@@ -313,7 +340,6 @@ def test_dismiss_variant(adapter, institute_obj, case_obj, user_obj, variant_obj
 
 
 def test_matching_dismissed_variant(adapter, institute_obj, case_obj, user_obj, variant_obj):
-
     # GIVEN a variant db with at least one variant, and no events
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
@@ -374,7 +400,6 @@ def test_matching_dismissed_variant(adapter, institute_obj, case_obj, user_obj,
 
 
 def test_update_cancer_tier(adapter, institute_obj, case_obj, user_obj, variant_obj):
-
     # GIVEN a variant db with at least one variant, and no events
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
@@ -411,7 +436,6 @@ def test_update_cancer_tier(adapter, institute_obj, case_obj, user_obj, variant_
 
 
 def test_update_manual_rank(adapter, institute_obj, case_obj, user_obj, variant_obj):
-
     # GIVEN a variant db with at least one variant, and no events
     adapter.case_collection.insert_one(case_obj)
     adapter.institute_collection.insert_one(institute_obj)
