@@ -2,14 +2,12 @@
 from urllib.parse import urlencode
 
 import pymongo
-from flask import current_app, url_for
-from flask_login import current_user
+from flask import url_for
 
 from scout.server.extensions import store
 
 
 def test_variants_clinical_filter(app, institute_obj, case_obj, mocker, mock_redirect):
-
     mocker.patch("scout.server.blueprints.variants.views.redirect", return_value=mock_redirect)
 
     # GIVEN a variant without clinVar annotations
